summaryrefslogtreecommitdiff
path: root/tests/auto/gui/text/qtextformat/tst_qtextformat.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tests/auto/gui/text/qtextformat/tst_qtextformat.cpp')
-rw-r--r--tests/auto/gui/text/qtextformat/tst_qtextformat.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/auto/gui/text/qtextformat/tst_qtextformat.cpp b/tests/auto/gui/text/qtextformat/tst_qtextformat.cpp
index 4e5ef7c555..7548dbb8e4 100644
--- a/tests/auto/gui/text/qtextformat/tst_qtextformat.cpp
+++ b/tests/auto/gui/text/qtextformat/tst_qtextformat.cpp
@@ -155,7 +155,7 @@ void tst_QTextFormat::testUnderlinePropertyPrecedence()
QCOMPARE(format.fontUnderline(), false);
QCOMPARE(format.font().underline(), false);
// do it again, but reverse the ordering (we use a QVector internally, so test a LOT ;)
// create conflict. Should use the new property
format.setProperty(QTextCharFormat::FontUnderline, false);
format.setProperty(QTextCharFormat::TextUnderlineStyle, QTextCharFormat::SingleUnderline);
@@ -210,7 +210,7 @@ void tst_QTextFormat::resolveFont()
fmt.setProperty(QTextFormat::FontItalic, true);
QTextCursor(&doc).insertText("Test", fmt);
- QVector<QTextFormat> formats = doc.allFormats();
+ QList<QTextFormat> formats = doc.allFormats();
QCOMPARE(formats.count(), 3);
QCOMPARE(formats.at(2).type(), int(QTextFormat::CharFormat));
@@ -155,7 +155,7 @@ void tst_QTextFormat::testUnderlinePropertyPrecedence()
QCOMPARE(format.fontUnderline(), false);
QCOMPARE(format.font().underline(), false);
- // do it again, but reverse the ordering (we use a QVector internally, so test a LOT ;)
+ // do it again, but reverse the ordering (we use a QList internally, so test a LOT ;)
// create conflict. Should use the new property
format.setProperty(QTextCharFormat::FontUnderline, false);